// GSV86CAN.h

#ifndef __GSV86CANH__
#define __GSV86CANH__

#ifdef __cplusplus
extern "C" {
#endif

#define CALLTYPE __stdcall

// defines
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

#define GSV_STD_ADR_RESPONSE	0x101		// device identifier 
#define GSV_STD_ADR_COMMAND		0x100		// system identifier

// Return-codes for simple errorcode
#define GSV_OK		0	// no error, without signalling information
#define GSV_ERROR	-1	// an error occurred within the request
#define GSV_TRUE	1	// no error, with signalling information

// constants for 6-axis oparations
#define SENSORCAL_TYP_SERNO			0
#define SENSORCAL_TYP_MATRIX_NORM	1
#define SENSORCAL_TYP_MATRIX		2
#define SENSORCAL_TYP_OFFSET		3
#define SENSORCAL_TYP_MAXVAL		4
#define SENSORCAL_TYP_INSENS		5
#define SENSORCAL_MATRIX_NORM_DEF	5.0
#define SENSORCAL_INSENS_DEF		2.0
#define SENSORCAL_OFFSET_DEF		0
#define SENSORCAL_TYP_TEDS_MEM		0x80
#define SENSORCAL_TYP_EEPROM_MEM	0
#define SENSORCAL_VECTOR_SIZE		6
#define SENSORCAL_MATRIX_SIZE		36
#define SENSORCAL_OFFSET_SIZE		3
#define SENSORCAL_MAXVAL_SIZE		6

// serial number constants
#define SER_NO_SIZE			8
#define SER_NO_CHAR_SIZE	SER_NO_SIZE+1	// inclusive termination
#define SERNO_MIN			0
#define SERNO_MAX			99999999

// Constants for GetInTypeRange, GetAllInTypesRanges and GsetInType
#define INTYP_BRIDGE_US875	0	// Input-Type Bridge at Vexcitation= 8.75V 
#define INTYP_BRIDGE_US5	1	// Input-Type Bridge at Vexcitation= 5V
#define INTYP_BRIDGE_US25	2	// Input-Type Bridge at Vexcitation= 2.5V
#define INTYP_SE10			3	// Input-Type single-endend +-10V
#define INTYP_PT1000		4	// Input-Type Temperature-Sensor PT1000
#define INTYP_TEMP_K		5	// Input-Type Temperature-Sensor Type-K

// Constants for GetUnitText and SetUnitText */
#define UNIT_WIDTH			8		// maximum width of unit text array incl. termination
#define ACTIVE_UNIT_ANY		0x00	// GetUnitText: Read active unit. SetUnitText: Set and activate any unit
#define USER_UNIT_1			0x01	// GetUnitText: Read user defined unit string 1. SetUnitText: Set and activate user defined unit string 1.
#define USER_UNIT_2			0x02	// GetUnitText: Read user defined unit string 2. SetUnitText: Set and activate user defined unit string 2.
#define SET_FIXED_UNIT		0x10	// SetUnitText: Set and activate fixed unit (UnitNo set)
#define WRITE_USER_UNIT_1	0x11	// SetUnitText: Write user unit string 1 (not activated)
#define WRITE_USER_UNIT_2	0x12	// SetUnitText: Write user unit string 2 (not activated)
#define ANSI_CODEPAGE		0x00000000	// ANSI 8-Bit coded
#define ASCII_ONLY			0x00000100	// Use ASCII 7-Bit only
#define DOS_CODEPAGE_437	0x0001B500	// DOS/Windows Codepage 437
#define WIN_CODEPAGE_1252	0x0004E400	// Windows Codepage 1252

// Constants for digital filter
#define FILT_CHARACT_LP	0x00	// low pass
#define FILT_CHARACT_HP	0x01	// high pass
#define FILT_CHARACT_BP	0x02	// band pass
#define FILT_CHARACT_BS	0x03	// band stop

#define FILT_ORDER_IIR		4	// As by now, filter order is constant for IIR filter
#define FILT_ORDER_FIR		9	// As by now, filter order is constant for FIR filter

#define FILT_CLASS_IIR		0	// filter class definition 
#define FILT_CLASS_FIR		1	// filter class definition

#define FILT_TYPE_IIR		0x00	// mask or for IIR-Type
#define FILT_TYPE_FIR		0x80	// mask or for FIR-Type


// datatypes
#define DATATYP_INT16	1	// datatype is 16-Bit
#define DATATYP_INT24	2	// datatype is 24-Bit
#define DATATYP_FLOAT	3	// datatype is 32-Bit Float

// supported CAN adapter (manufactur)
#define CANADAPTERTYPE_PCAN			0x01		// PCAN

// flags for initialisation
#define AE_FLAG_SHOWCAN				0x0002		// show can messages on console output
#define AE_FLAG_LOGCAN				0x0004		// create a logfile and log all messages
#define AE_FLAG_TYPEGSV6			0x0010		// set type GSV-6
#define AE_FLAG_TYPEGSV8			0x0020		// set type GSV-8

// last error on device or dll
#define ERROR_SPACE_DLL             0x01		// reading LastError from dll
#define ERROR_SPACE_DEVICE          0x02		// reading LastError from device

/* Constants for GSV86CANsimulateDfilter. May be ORed with FILT_TYPE_FIR */
#define SIMUL_DFILT_FREQ_RESPONSE 1 /* simulate frequency response (frequency domain)*/
#define SIMUL_DFILT_STEP_RESPONSE 2 /* simulate step response (time domain)*/

// api for GSV dll
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

	/***********************************************************************************************************************
	Open CAN device
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number (to be assigned for subsequent use)
	\in   CanType				type of CAN adapter - CANADAPTERTYPE_PCAN
	\in   Bitrate				CAN baudrate in bit/sec. (e.g. 1000000 or 500000)
	\in   BufSize				size if dynamic buffer per channel
	\out  Count					number of active channels for measuring
	\in   CommandIndentifier	CAN message id for commands
	\in   ResponseIndentifier	CAN message id for answers
	\in   Flags					AE_FLAG - minimun set _TYPEGSV6 or _TYPESGV8
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	Assign DevNo a specific Device identified by the other paramters and interface definition.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int CALLTYPE	GSV86CANactivateExtended(int DevNo, int CanType, unsigned long Bitrate, unsigned long BufSize, int *Count, unsigned long CommandIndentifier, unsigned long ResponseIndentifier, long Flags);

	/***********************************************************************************************************************
	Open CAN device with std values
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number, to be assigned
	\out  Count					number of active channels for measuring
	\return						simple errorcode: GSV_OK on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	Wrapper to GSV86CANActivateExtended with the following paramteres:
	   CanType				CANADAPTERTYPE_PCAN
	   Bitrate				1000000
	   BufSize				0xFFFE
	   CommandIndentifier	GSV_STD_ADR_COMMAND
	   ResponseIndentifier	GSV_STD_ADR_RESPONSE
	   Flags				AE_FLAG_TYPEGSV6
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANactivateStd(int DevNo, int *Count);

	/***********************************************************************************************************************
	Clear the device buffer in device
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\return						simple errorcode: GSV_OK on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANclearDeviceBuf(int DevNo);

	/***********************************************************************************************************************
	Clear the device buffer in dll
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int CALLTYPE	GSV86CANclearDLLbuffer(int DevNo);

	/***********************************************************************************************************************
	Clear the maximum value
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\in   Chan					channel number
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANclearMaximumValue(int DevNo, int Chan);

	/***********************************************************************************************************************
	Reading the version of the DLL
	------------------------------------------------------------------------------------------------------------------------
	\out  Version				DLL version
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int CALLTYPE	GSV86CANDllVersion(unsigned long* Version);

	/***********************************************************************************************************************
	Reading the device firmware version
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\out  Version				Bits<31:16>: firmware version major
								Bits<15:0>: firmware version minor
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANgetFirmwareVersion(int DevNo, unsigned long* Version);

	/***********************************************************************************************************************
	Get all available input types and ranges
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\in   Chan					input channel number, 1..8
	\out  Number				number of sensortypes
	\out  InTypes				If not NULL: pointer to array of int, where the existent input types
								are written to. Type definition:
								#define INTYP_BRIDGE_US875 	0	Input-Type Bridge at Vexcitation=8,75V
								#define INTYP_BRIDGE_US5 	1	Input-Type Bridge at Vexcitation=5V
								#define INTYP_BRIDGE_US25 	2	Input-Type Bridge at Vexcitation=2,5V
								#define INTYP_SE10 			3	Input-Type single-endend +-10V
								#define INTYP_PT1000		4	Input-Type Temperature-Sensor PT1000
								#define INTYP_TEMP_K		5	Input-Type Temperature-Sensor Type-K
	\out  Ranges				If not NULL: pointer to array of double, where the existent input ranges
								(sensitivities) are written to. The meaning depends on corresponding InType,
								which has the same index in InTypes array. See above.
								Array sizes should be MAX_INPUT_TYPES_NUM
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANgetAllInTypesRanges(int DevNo, int Chan, int *Number, int* InTypes, double* Ranges);

	/***********************************************************************************************************************
	Get analogue filter settings
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\out  Filter				filter frequency
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANreadAnalogueFilter(int DevNo, unsigned int *Filter);

	/***********************************************************************************************************************
	Get analogue output type
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\in   Chan					input channel number, 1..8
	\out  Enum					type:
									0 ==   0V  - 10V
									1 == -10V  - 10V
									2 ==   0V  - 5V
									3 ==  -5V  - 5V
									4 ==   4mA - 20mA
									5 == OFF
									6 ==   0mA - 20mA
	\out  Mode					operating mode:
								Bits: <7:2>
									reserved
								Bits: <1> 
									0 == output channel active
									1 == output channel inactive
								Bits: <0>
									0 == DAC follows measurevalues
									1 == direct mode
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANgetAoutType(int DevNo, int Chan, unsigned char *Enum, unsigned char *Mode);

	/***********************************************************************************************************************
	Get calibration value
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\in   Chan					channel number (base 0):
									GSV-6:
										0x00-0x05: input factor
										0x08-0x0D: input offset
										0x10:	   output factor
										0x18:      output offset
										0x20-0x25: scale value (factor)
										0x28-0x2D: tara value (offset)
									GSV-8:
										0x00-0x07: input factor
										0x08-0x0F: input offset
										0x10-0x17: output factor
										0x18-0x1F: output offset
	\in   Ix					subindex:
									input factor / offset:
									0x00: amplification 1x
									0x01: amplification 2x
									0x02: amplification 4x
									0x03: amplification 8x
									output factor / offset:
									0x00:   0V  - 10V
									0x01: -10V  - 10V
									0x02:   0V  - 5V
									0x03:  -5V  - 5V
									0x04:   4mA - 20mA
									0x05: reserved
									0x06:   0mA - 20 mA
									0x07: reserved
								scale- / tara values
									unused
	\out  Cal					pointer to factor (float) or offset (int32_t)
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANreadCal(int DevNo, int Chan, int Ix, double* Cal);

	/***********************************************************************************************************************
	Get CAN settings
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\in   Index					index:
									0: CAN_IN command CAN-ID
									1: CAN_OUT response CAN-ID
									2: CAN_CV value frame CAN-ID
									3: CAN_CAST multicast CAN-ID
									4: CAN_BAUD baudrate (in Hz)
									5: CAN_FLAGS
	\out  Settings				current setting
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANgetCANSettings(int DevNo, int Index, unsigned long *Settings);

	/***********************************************************************************************************************
	Get available commands
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\in   Commands				pointer to:
									byte 0 = HighCommand
									byte 1 = LowCommand
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANgetCommandAvailable(int DevNo, unsigned char *Commands);

	/***********************************************************************************************************************
	Get operating hours
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\in   Abs					counter:
									0: permanent
									1: resetable
	\out  DevHours				pointer to counted hours
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANreadDeviceHours(int DevNo, int Abs, double *DevHours);

	/***********************************************************************************************************************
	Get digital filter coefficients 
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo				device handle number
	\in   Chan				input channel number, 1..8
							or -1: get from DLL only (was set by previous call to GSV86CANcalcSetDfilterParams with Chan=-1
	\in   Type				type: 
								0x00 = FILT_TYPE_IIR: Get Filter Coefficients for the IIR filter
								0x80 = FILT_TYPE_FIR: Get Filter Coefficients for the FIR filter
	\out Coeff				pointer to double array of min. size =9.
								IIR filter: the first 5 items contain the a coefficients a0..a4, a0 at index 0.
								FIR filter: the 9 FIR coefficients a0..a8, a0 at index 0.
	\out CoeffB				pointer to double array of min. size =4.
								IIR filter: the 4 items contain the b coefficients b0..b3, with b0 at index 0.
								FIR filter: Can be NULL.
	\return					simple errorcode: GSV_OK, on success or GSV_ERROR on failure
								If GSV_ERROR is returned, then a more detailed error information can be retrieved with
								GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANgetDfilterCoeff(int DevNo, int Chan, int Type, double* Coeff, double* CoeffB);

	/***********************************************************************************************************************
	Get digital filter enabled or disabled
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\out  State					On/Off state(s): 
									On/Off state in Bits<7:0> (GSV-8) or on Bits<5:0> (GSV-6).
										Bit=1: Filter enabled, =0: disabled;
										bit 0 is corresponding to channel 1, ..., bit 7 to channel 8
									GSV-6:
										Bits<5:0> represents the active filter
									GSV-8:
										Bits<7:0> represents IIR-Filter
										Bits<15:8> represents FIR-Filter
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANgetDfilterOnOff(int DevNo, unsigned long *State);

	/***********************************************************************************************************************
	Get digital filter type
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\in   Chan					input channel number, 1..8
	\in   Typen					type:
									0x00 = FILT_TYPE_IIR (GSV-8 only)
									0x80 = FILT_TYPE_FIR (GSV-8 only)
	\out TypeOut				pointer to type:
								Bits: <7>
									FIR Filter indicator
								Bits: <6:4> 
									Filtertyp:
										0 == low-pass
										1 == high-pass
										2 == band-pass
										3 == band-stop
								Bits: <3:0>
									filterlength
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANgetDigiFiltType(int DevNo, int Chan, int TypeIn, int *TypeOut);

	/***********************************************************************************************************************
	Get supported equipment
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\out  Equipment				pointer to equipment:
								Bit <0> HAS_ADC
								Bit <1> HAS_ETHERCAT
								Bit <2> HAS_LCD
								Bit <3> HAS_TEDS
								Bit <4> HAS_DIGI_IN
								Bit <5> HAS_DIGI_OUT
								Bit <6> HAS_ANALOG_OUT
								Bit <7> HAS_SERIAL
								Bit <8> HAS_FREQ_OUT
								Bit <9> HAS_AIN_MCU
								Bit <10> HAS_SIXAXIS
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANgetSoftwareConfiguration(int DevNo, unsigned long *Equipment);

	/***********************************************************************************************************************
	Get datarate for output values
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\out  Frequency				pointer to frequency
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANgetFrequency(int DevNo, double *Frequency);

	/***********************************************************************************************************************
	Get the activated ID-state
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\out  IdState				pointer to state
								 0 = normal operation
								 8 = privileged operation
								10 = ME-command operation
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANgetIDState(int DevNo, unsigned char *IdState);

	/***********************************************************************************************************************
	Get the interface description
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\in   StopPermTX			stop transfer
								0 = no changing
								1 = stop transfer
								2 = start transfer
	\out  Ident					current device description
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANgetInterfaceIdent(int DevNo, int StopPermTX, int* Ident);

	/***********************************************************************************************************************
	Get type and range of an input channel
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\in   Chan					input channel number, 1..8
	\out  InType				pointer to inputtype
	\out  Range					pointer to range
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANgetInTypeRange(int DevNo, int Chan, int *InType, double* Range);

	/***********************************************************************************************************************
	Get the last error
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\in   Errorspace			source of the error
								1 = DLL
								2 = Device
	\in   Index					index of errortype (only in devices)
								0 = protocoll error
								1 = async error
	\out  LastError				pointer to last error
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANgetLastProtocolError(int DevNo, int ErrorSpace, int Index, unsigned long* LastError);

	/***********************************************************************************************************************
	Get the last error of measured data
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\in   Index					index always = 0
	\out  Error					pointer to errorbits (max. 6 bytes)
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANgetLastValueError(int DevNo, int Index, unsigned char* Error);


	/***********************************************************************************************************************
	Get the last error text
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\out  ErrorText				pointer to errortext (256 Bytes)
	\out  ErrorCode				pointer to error code
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int CALLTYPE	GSV86CANgetLastErrorText(int DevNo, char* ErrorText, unsigned long* ErrorCode);

	/***********************************************************************************************************************
	Get the stored maximum and minimum measured data
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\in   Chan					input channel number, 1..8
	\out  Min					pointer to minimum
	\out  Max					pointer to maximum
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANreadMaxMinVal(int DevNo, int Chan, double *Min, double *Max);

	/***********************************************************************************************************************
	Get the mode-flags
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\out  Mode					pointer to mode
								GSV-6:
									<2:0> number of active channels
										0b001: 1 channel
										0b010: 2 channel
										0b011: 3 channel
										0b110: 6 channel
									<3> save-tara
									<4> user-monitor
									<6> scale-negate
									<7> peak value presentation
									<8> peak value reset and tara
									<9> read TEDs on startup
									<10> 6-axis calculation

								GSV-8:
									<0> active 6-axis calculation
									<1> setting analog filter automatically
									<2> calculate maximum value
									<3> active noise suppression
									<7> disable all write-functions
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANgetMode(int DevNo, unsigned long *Mode);

	/***********************************************************************************************************************
	Get the threshold for noise suppression
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\in   Chan					input channel number, 1..8
	\out  NoiseCutThreshold		pointer to threshold
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANgetNoiseCutThreshold(int DevNo, int Chan, double *NoiseCutThreshold);

	/***********************************************************************************************************************
	Get the scaleing factor
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\in   Chan					input channel number, 1..8
	\out  Norm					pointer to scaling factor
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANreadUserScale(int DevNo, int Chan, double* Norm);

	/***********************************************************************************************************************
	Get the hardware version [reserved]
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\out  Options				pointer to options
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANgetHardwareVersion(int DevNo, unsigned long *Options);

	/***********************************************************************************************************************
	Get the raw value
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\in   Chan					input channel number, 1..8
	\out  RawValue				pointer to raw value
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANgetRawValue(int DevNo, int Chan, long* RawValue);

	/***********************************************************************************************************************
	Get the active sensor matrix number
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\in   Chan					input channel number, 1..8
	\out  CalArrNo				pointer to the storage space for the following bytes:
								byte 1: maximum of matrices
								byte 2: maximum of stored matrices
								byte 3: active matrix slot-number
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANgetFTSensorCalArrNo(int DevNo, int Chan, unsigned char *CalArrNo);

	/***********************************************************************************************************************
	Get the device serialnumber
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\out  SerNo					pointer to serialnumber storage
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANgetSerialNo(int DevNo, unsigned long *SerNo);

	/***********************************************************************************************************************
	Get mapping of value to channel
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\in   Index					mapping index
	\out  Mapping				pointer to mapping
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANgetTXMapping(int DevNo, unsigned char Index, unsigned int* Mapping);

	/***********************************************************************************************************************
	Get the transmission mode and the data representation
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\in   Index					index
								0 = TX-mode
								1 = data value format
								2 = maximum number of channels
	\out  Flags					pointer to flags
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANgetTXmode(int DevNo, int Index, int *Flags);

	/***********************************************************************************************************************
	Get the active unit number
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\in   Chan					input channel number, 1..8
	\out  UnitNo				pointer to number
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANgetUnitNo(int DevNo, int Chan, int *UnitNo);

	/***********************************************************************************************************************
	Get the text of a unit
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\in   Chan					input channel number, 1..8
	\in   Code					control value, consisting of unit type (Bits <7:0> and code page value (Bits <23:8>)
								bits <23:8>: Code page. Only used if unit set by UnitNo (Bits<7:0>=0). Supported values:
									ANSI_CODEPAGE =0x0000: ANSI 8-bit
									ASCII_ONLY 0x0001: Strictly 7-Bit ASCII only (micro sign ->'u', degree sign left away, per mille->0/00) 
									DOS_CODEPAGE_437 0x01B5 (437d): Windows/DOS codepage 437
									WIN_CODEPAGE_1252 0x04E4 (1252d): Windows codepage 1252
								bits<7:0>: Unit type to read:
									ACTIVE_UNIT_ANY =0: Read active unit (as set by unit-no, see GSV8getUnitNo)
									USER_UNIT_1 =1: Read user-defined unit string number 1 (Chan ignored)
									USER_UNIT_2 =2: Read user-defined unit string number 2 (Chan ignored)
	\out  UnitText				poiner to char array: Unit-Text to read, ANSI-coded 
								Must be at least 8 chars in length
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANgetUnitText(int DevNo, int Chan, int Code, char* UnitText);

	/***********************************************************************************************************************
	Get the user offset
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\in   Chan					input channel number, 1..8
	\out  Offset				poiner to offset
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANreadUserOffset(int DevNo, int Chan, double* Offset);
	
	/***********************************************************************************************************************
	Get one measurement value of all active channels
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANgetValue(int DevNo);

	/***********************************************************************************************************************
	Load a setup
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\in   DataSetNo				number of dataset:
								0 = last setup
								1 = factory default
								2..6 = user setup (GSV-8 only)
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANloadSettings(int DevNo, int DataSetNo);

	/***********************************************************************************************************************
	read one value
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\in   Chan					input channel number, 1..8
	\out  out					poiner to value
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANread(int DevNo, int Chan, double* out);

	/***********************************************************************************************************************
	Get single calibration value of six-axis sensor calibration
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\in   typ					requesttype
								0: SERNO serialnumber (ix: 0)
								1: NORM scale factor (ix: 0)
								2: MATRIX value (ix: 0..35)
								3: OFFSET value (ix: 0..5)
								4: MAXVAL maximum value (ix 0..5)
								5: INSENS sensetivity (ix: 0)
	\in  ix						arrayindex
	\out val					poiner to value
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANreadFTSensorCalValue(int DevNo, int typ, int ix, double* val);

	/***********************************************************************************************************************
	Get single calibration value of six-axis sensor calibration
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\in   MemType				requesttype alway 0
	\out  SensorSerNo			serialnumber of the sensor
	\out  MatrixNorm			scale factor
	\out  InSens				input sensetivity
	\out  Matrix				value
	\out  Offset				value
	\out  MaxVals				value
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANreadFTSensorCalArray(int DevNo, int MemType, unsigned char* SensorSerNo, double* MatrixNorm, double* InSens, double* Matrix, double* Offsets, double* MaxVals);

	/***********************************************************************************************************************
	read analogue output scale
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\in   Chan					input channel number, 1..8
	\out  Scale					pointer to scale value
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANreadAoutScale(int DevNo, int Chan, double *Scale);

	/***********************************************************************************************************************
	read some measurement values
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\in   Chan					input channel number, 1..8
	\in   count					number of data values
	\out  out					data value - pointer to array of values (min. arraysize = count)
	\out  valsread				nummer of amount values 
	\out  ErrFlags				errorflags - pointer to array of errorflags (min. arraysize = count)
	\return						simple errorcode:
								GSV_OK, if (at least one) buffer is emty and no values were read, or 
								GSV_TRUE if value(s) were read, or
								GSV_ERROR if an (internal) error occurred. Remark: Value-related error flags set by device
								have no impact on the return value (i.e. *ErrFlags !=0 : return GSV_TRUE)
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANreadMultiple(int DevNo, int Chan, double *out, int count, int* valsread, int* ErrFlags);

	/***********************************************************************************************************************
	read the analogue output offset
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\in   Chan					input channel number, 1(GSV-6), 1..8 (GSV-8)
	\out  Offset				offset value
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANreadAoutOffset(int DevNo, int Chan, double *Offset);

	/***********************************************************************************************************************
	read the the serialnumber of the stored sensor
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\in   MemType				requesttype always 0
	\out  SensorSerNo			pointer to sensor serialnumber
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANreadFTSensorSerNo(int DevNo, int MemType, unsigned char* SensorSerNo);

	/***********************************************************************************************************************
	read stored tara value
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\in   Chan					input channel number, 1..8
	\out  Zero					pointer to tara
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANreadZero(int DevNo, int Chan, long *Zero);

	/***********************************************************************************************************************
	reset status of device
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANresetStatus(int DevNo);

	/***********************************************************************************************************************
	set analogue filterfrequency (GSV-8 only)
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\in   Filter				frequency
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANwriteAnalogueFilter(int DevNo, unsigned int Filter);

	/***********************************************************************************************************************
	set analogue output direct to given value (GSV-8 only)
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\in   Chan					input channel number, 1..8
	\in   Code					DAC-code
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANwriteAoutDirect(int DevNo, int Chan, unsigned int Code);

	/***********************************************************************************************************************
	set analogue output type (GSV-8 only)
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\in   Chan					input channel number, 1..8
	\in   Enum					output type:
									0 =   0V  - 10V
									1 = -10V  - 10V
									2 =   0V  -  5V
									3 =  -5V  -  5V
									4 =   4mA - 20mA
									5 =   OFF
									6 =   0mA - 20mA
	\in Mode					channel mode:
								bit <1> output
									0 = active
									1 = inactive
								bit <0> direct mode active
									0 = measurement mode
									1 = direct mode
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANsetAoutType(int DevNo, int Chan, unsigned char Enum, unsigned char Mode);

	/***********************************************************************************************************************
	set calibration values
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\in   Chan					channel number (base 0):
								GSV-6:
									0x00-0x05: input factor
									0x08-0x0D: input offset
									0x10:	   output factor
									0x18:      output offset
									0x20-0x25: scale value (factor)
									0x28-0x2D: tara value (offset)
								GSV-8:
									0x00-0x07: input factor
									0x08-0x0F: input offset
									0x10-0x17: output factor
									0x18-0x1F: output offset
	\in   Ix					subindex
								input factor / offset:
									0x00: amplification 1x
									0x01: amplification 2x
									0x02: amplification 4x
									0x03: amplification 8x
								output factor / offset:
									0x00:   0V  - 10V
									0x01: -10V  - 10V
									0x02:   0V  - 5V
									0x03:  -5V  - 5V
									0x04:   4mA - 20mA
									0x05: reserved
									0x06:   0mA - 20 mA
									0x07: reserved
								scale- / tara values
									unused
	\in   Cal					calibration value
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANMEwriteCal(int DevNo, int Chan, int Ix, double Cal);

	/***********************************************************************************************************************
	set setup for CAN-communication
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\in   Index					dataset index:
									0: CAN_IN command Can-ID
									1: CAN_OUT response Can-ID
									2: CAN_CV value Can-ID
									3: CAN_CAST multicast Can-ID
									4: CAN_BAUD baudrate (in Hz)
									5: CAN_FLAGS
	\in   Settings				value:
									can-ID:
									0x00000000-0x000007FF: std-id
									0x80000000-0x9FFFFFFF: ext-id
									baudrate:
									1000000, 500000, 250000, 125000, 100000, 50000, 25000, 12500, 10000
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANsetCANSettings(int DevNo, int Index, unsigned long Settings);

	/***********************************************************************************************************************
	set working hours from the device
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\in   Index					dataset index:
	\in   DevHours				device hours
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANwriteDeviceHours(int DevNo, double DevHours);

	/***********************************************************************************************************************
	(de)activate digital filters
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\in   Chan					input channel number, 1..8
	\in   Type					type of filter (IIR, FIR)
	\in   OnOff					bits representing:
								GSV-6:
									<5:0> filter on channel active
								GSV-8:
									<7:0> IIR-filter on channel active
									<15:8> FIR-filter on channel active
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANsetDfilterOnOff(int DevNo, int Chan, int Type, int OnOff);

	/***********************************************************************************************************************
	set the complete digital filert parameter
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\in   Chan					input channel number, 1..6 (GSV-6), 1..8 (GSV-8)
	\in   Type					Type of filter. Bit7: =0: IIR, =1: FIR
									Bits<6:4>: =0: Low pass, =1: high pass, =2: band pass, =3: band stop
									Bits<3:0>: Filter order (as by now, 4 for IIR, 9 for FIR allowed)
	\in   CutRatio				pointer to double array of min. size=2.
									Index 0: the low -3dB Cutoff frequency ratio fg/Fs
									Index 1: the high -3dB Cutoff frequency ratio fgo/Fs for Band pass and Band stop filter.
	\in   Coeff					pointer to double array of min. size =9.
									IIR filter: the a coefficients a0..a4 are expected, with a0 at index 0.
									FIR filter: the 9 FIR coefficients are expected, with a0 at index 0
	\in   CoeffB				pointer to double array of min. size =4.
									IIR filter: the b coefficients b0..b3 are expected, with b0 at index 0.
									FIR filter: can be NULL.
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANsetDfilterParams(int DevNo, int Chan, int Type, double* CutRatio, double* Coeff, double* CoeffB);
	/***********************************************************************************************************************
	set data rate
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\in   frequency				output data rate
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANsetFrequency(int DevNo, double frequency);

	/***********************************************************************************************************************
	set the ID-level
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\in   Id					pointer to the id
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANsetID(int DevNo, const char* Id);

	/***********************************************************************************************************************
	set input type
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\in   Chan					input channel number, 0..8 (GSV-8), 0 sets all channels
	\in   InType				input type:
									INTYP_BRIDGE_US875	0	Input-Type Bridge at Vexcitation=8,75V
									INTYP_BRIDGE_US5	1	Input-Type Bridge at Vexcitation=5V
									INTYP_BRIDGE_US25	2	Input-Type Bridge at Vexcitation=2,5V
									INTYP_SE10 			3	Input-Type single-endend +-10V
									INTYP_PT1000		4	Input-Type Temperature-Sensor PT1000
									INTYP_TEMP_K		5	Input-Type Temperature-Sensor Type-K
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANsetInType(int DevNo, int Chan, int InType);
	
	/***********************************************************************************************************************
	set mode-flags
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\in   Mode					mode-bits:
								GSV-6:
									<10> active 6-axis calculation
								GSV-8:
									<0> active 6-axis calculation
									<1> setting analog filter automatically
									<2> calculate maximum value
									<3> active noise suppression
									<7> disable all write-functions
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANsetMode(int DevNo, unsigned long Mode);

	/***********************************************************************************************************************
	Set the threshold for noise suppression
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\in   Chan					input channel number, 0..8 (GSV-8), 0 sets all channels
	\in   NoiseCutThreshold		threshold
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANsetNoiseCutThreshold(int DevNo, int Chan, double NoiseCutThershold);

	/***********************************************************************************************************************
	Set the scaleing factor
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\in   Chan					input channel number, 0..6 (GSV-6), 0..8 (GSV-8), 0 sets all channels
	\in   Norm					scaling factor
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANwriteUserScale(int DevNo, int Chan, double Norm);

	/***********************************************************************************************************************
	Set the input sensetivity range
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\in   Chan					input channel number, 0..6 (GSV-6), 0..8 (GSV-8), 0 sets all channels
	\in   type					input type, 0 (GSV-6), 0..3 (GSV-8)
	\in   range					sensetivity (mV * 100):
									GSV-6:
										800: 8mV/V
										400: 4mV/V
										200: 2mV/V
										100: 1mV/V
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANMEwriteInputRange(int DevNo, int Chan, int type, double range);

	/***********************************************************************************************************************
	Set the active sensor matrix
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\in   CalArrNo				sensor matrix number
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANsetFTSensorCalArrNo(int DevNo, int CalArrNo);

	/***********************************************************************************************************************
	Set the device serialnumber
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\in   SerNo					pointer to serialnumber
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANsetSerialNo(int DevNo, unsigned long SerNo);

	/***********************************************************************************************************************
	Set mapping of value to channel (GSV-8 only)
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\in   Index					mapping index
	\in   Mapping				mapping dataset
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANsetTXMapping(int DevNo, unsigned char index, unsigned int mapping);

	/***********************************************************************************************************************
	Set the TX mode
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\in   Index					dataset index:
								0 = set TXmode flags
								1 = set measuring value format
	\in   TXmode				GSV-6:
									Index 0:
										bit <0> = 1, TX off temporarily
										bit <1> = 1, TX off permanent
									Index 1:
										1 = int16
										3 = float
								GSV-8:
									Index 0:
										bit <0> = 1, USB-TX off temporarily
										bit <1> = 1, USB-TX off permanent
										-	<6> block change on UART-setup
										-	<7> block change on USB-setup
									Index 1:
										1 = int16
										2 = S24
										4 = int32
										16 = float
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANsetTXmode(int DevNo, int Index, unsigned long TXmode);

	/***********************************************************************************************************************
	Set the channel specific unit
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\in   Chan					input channel number, 0..6 (GSV-6), 0..8 (GSV-8), 0 sets all channels
	\in   UnitNo				unit datasetnumber
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANsetUnitNo(int DevNo, int Chan, int UnitNo);

	/***********************************************************************************************************************
	Set the text for the channelspecific unit
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\in   Chan					input channel number, 0..6 (GSV-6), 0..8 (GSV-8), 0 sets all channels
    \in   Code					Control value, consisting of unit type (Bits <7:0> and code page value (Bits <23:8>)
								Bits <23:8>: Code page for interpreting UnitText. Only used if Bits<3:0>=0. Supported values:
									ANSI_CODEPAGE =0x0000: ANSI 8-bit
									ASCII_ONLY 0x0001: Strictly 7-Bit ASCII only (micro sign ->'u', degree sign left away or ^, per mille->0/00) 
									DOS_CODEPAGE_437 0x01B5 (437d): Windows/DOS codepage 437
									WIN_CODEPAGE_1252 0x04E4 (1252d): Windows codepage 1252
								Bits<7:0>: Storing method:
									ACTIVE_UNIT_ANY =0x00: If unit text corresponds to an available fixed unit, that one is activated (UnitNo set accordingly).
									Otherwise, user-defined unit string is written to the device at Unit-Text 1 and activated (UnitNo set to 0xFF)
								USER_UNIT_1 =0x01: User-defined unit string is written to the device at Unit-Text 1 and activated (UnitNo set to 0xFF)
								USER_UNIT_2 =0x02: User-defined unit string is written to the device at Unit-Text 2 and activated (UnitNo set to 0xFE)
								SET_FIXED_UNIT =0x10: If unit text corresponds to an available fixed unit, that one is activated (UnitNo set accordingly).
								Otherwise, nothing is set and an error is triggered.
								WRITE_USER_UNIT_1 =0x11: User-defined unit string is written to the device at Unit-Text 1, but not activated (UnitNo not set)
								WRITE_USER_UNIT_2 =0x12: User-defined unit string is written to the device at Unit-Text 2 but not activated (UnitNo not set)
	\in UnitText				poiner to string with Unit-Text to set, maximum text-length is 7 chars
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANsetUnitText(int DevNo, int Chan, int Code, char* UnitText);

	/***********************************************************************************************************************
	set the user offset
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\in   Chan					input channel number, 0..6 (GSV-6), 0..8 (GSV-8), 0 sets all channels
	\in   Offset				user offset
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANwriteUserOffset(int DevNo, int Chan, double Offset);

	/***********************************************************************************************************************
	set the actual input value as tara
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\in   Chan					input channel number, 0..6 (GSV-6), 0..8 (GSV-8), 0 sets all channels
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANsetZero(int DevNo, int Chan);

	/***********************************************************************************************************************
	start value transmit
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANstartTX(int DevNo);

	/***********************************************************************************************************************
	stop value transmit
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANstopTX(int DevNo);

	/***********************************************************************************************************************
	store the active filter for selected channels
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\in   ChanStart				input channel number, 0..5 (GSV-6), 0..7 (GSV-8)
	\in   ChanEnd				input channel number, 0..5 (GSV-6), 0..7 (GSV-8)
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANstoreDigitalFilter(int DevNo, int ChanStart, int ChanEnd);

	/***********************************************************************************************************************
	store the calibration matrix for 6-axis calculation from ram to flash
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\in   CalArray				flash index
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANstoreFTSensorCal(int DevNo, int CalArray);

	/***********************************************************************************************************************
	store the working settings
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\in   DataSetNo				number of dataset
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANstoreSettings(int DevNo, int DataSetNo);

	/***********************************************************************************************************************
	set writeprotection
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\in   Blockid				pointer to protection code
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANswitchBlocking(int DevNo, char *Blockid);
	
	/***********************************************************************************************************************
	write the 6-axis calibration matrix for specific sensor
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\in   MemType				dataset offset always 0
	\in   SensorSerNo			sensor serialnumber
	\in   MatrixNorm			scale factor
	\in   InSens				input sensetivity
	\in   Matrix				matrix values (max. SENSORCAL_MATRIX_SIZE)
	\in   Offsets				offset values (max. SENSORCAL_OFFSET_SIZE)
	\in   MaxVals				max. values (max. SENSORCAL_MAXVAL_SIZE)
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANwriteFTSensorCalArray(int DevNo, int MemType, const char* SensorSerNo, double MatrixNorm, double InSens, double* Matrix, double* Offsets, double* MaxVals);

	/***********************************************************************************************************************
	write the analogue output scale
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\in   Chan					input channel number, 0..6 (GSV-6), 0..8 (GSV-8), 0 sets all channels
	\in   Scale					scale factor
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANwriteAoutScale(int DevNo, int Chan, double Scale);
	
	/***********************************************************************************************************************
	write the offset for the selected channel
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\in   Chan					input channel number, 0..6 (GSV-6), 0..8 (GSV-8), 0 sets all channels
	\in   Offset				offset value
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANwriteAoutOffset(int DevNo, int Chan, double Offset);

	/***********************************************************************************************************************
	write the zero/tara for the selected channel
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\in   Chan					input channel number, 0..6 (GSV-6), 0..8 (GSV-8), 0 sets all channels
	\in   Zero					zero/tara value
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANwriteZero(int DevNo, int Chan, long Zero);

	/***********************************************************************************************************************
	read the number of received data values
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\in   Chan					input channel number, 1..8
	\in   Received				pointer to number of received values
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int CALLTYPE	GSV86CANreceived(int DevNo, int Chan, unsigned long *Received);

	/***********************************************************************************************************************
	Calculate and set Digital Filter Parameters
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\in   Chan					input channel number, 1..6 (GSV-6), 1..8 (GSV-8)
								-1 = do not send data to the connected GSV
	\in   Class					filter class:
									0 = IIR
									1 = FIR
	\in   Charac				filter characteristic:
									0 = Low pass
									1 = high pass
									2 = band pass
									3 = band stop
	\in   Type					filter type:
									1 = Bessel
									2 = Butterworth
	\in   Order					filter length:
									4 = IIR
									9 = FIR
	\in   CutOff				cut off frequency low
	\in   CutOffHi				cut off frequency high
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int CALLTYPE	GSV86CANcalcSetDfilterParams(int DevNo, int Chan, int Class, int Type, int Charac, int Order, double CutOff, double CutOffHi);
	/***********************************************************************************************************************
	Close devicehandle and free all associated dll-ressources.
	should be called at progarm end.
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANrelease(int DevNo);
	
	/***********************************************************************************************************************
	Open a sensor description file and a matrix file and write the sensor calibration data to the gsv
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\in   MemType				dataset offset always 0
	\in   DatFilePath			path and filename of the sensor calibration matrix
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int	CALLTYPE	GSV86CANwriteFTSensorCalFromFile(int DevNo, int MemType, const char* DatFilePath);
	
	/***********************************************************************************************************************
	get the activated filter setup of the channel
	------------------------------------------------------------------------------------------------------------------------
	\in   DevNo					device handle number
	\in   Chan					input channel number, 1..6 (GSV-6), 1..8 (GSV-8)
	\in   TypeIn				input filter characteristic:
									0x00 = FILT_TYPE_IIR
									0x80 = FILT_TYPE_FIR
	\out  TypeOut				filter type:
									0 = low pass
									1 = high pass
									2 = band pass
									3 = band stop
	\out  CouOff				pointer to cut frequency (min. arraysize = 2)
	\return						simple errorcode: GSV_OK, on success or GSV_ERROR on failure
									If GSV_ERROR is returned, then a more detailed error information can be retrieved with
									GSV86CANgetLastProtocolError.
	------------------------------------------------------------------------------------------------------------------------
	\author       Sven Seidler-Ravelo Skibba
	\date         2015-04-22
	------------------------------------------------------------------------------------------------------------------------
	\revision     V1.0
	***********************************************************************************************************************/
	int CALLTYPE	GSV86CANgetDfilterInfo(int DevNo, int Chan, int TypeIn, int* TypeOut, double* CutOff);
	
/*************************************************************************************
	Digital Filter time-domain simulation
--------------------------------------------------------------------------------------
 \in \in   DevNo					device handle number
 	Analyze_Ftyp: one of
 		SIMUL_DFILT_FREQ_RESPONSE get Frequency response
 		SIMUL_DFILT_STEP_RESPONSE get step response
 		To simulate FIR filter, OR with FILT_TYPE_FIR
 	StartVal: First frequency if Analyze_Ftyp=SIMUL_DFILT_FREQ_RESPONSE
 		Start value (before step) if Analyze_Ftyp=SIMUL_DFILT_STEP_RESPONSE (standard step: =0)
 	EndVal: Last frequency if Analyze_Ftyp=SIMUL_DFILT_FREQ_RESPONSE
 		Step value (after step) if Analyze_Ftyp=SIMUL_DFILT_STEP_RESPONSE (standard step: =1)
 	Fa:	Sampling frequency = Data rate
 	Points: Number of simulated points (frequencies or samples, respective)
 	Filepath: Full path to file, where results are written to. File should not exist before;
 		otherwise, it will be overwritten.
 \return Simple errorcode: GSV_OK,if successful or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
 Additional possible error codes:
 #define DF_ERR_NOT_INIT 0x30000201 GSV86calcSetDfilterParams not called before
 #define DF_ERR_OPT_WRONG 0x30000202 wrong parameters
 #define DF_ERR_NO_CONVERGENCE 0x30000203 coefficient calculation failed to converge
 #define DF_ERR_COEFF_SUM_TOOBIG 0x30000208 coefficients are too big
--------------------------------------------------------------------------------------
 \remark: GSV86calcSetDfilterParams must be called before.
 	There, Chan can be set to -1 for simulation only (no device access).
--------------------------------------------------------------------------------------
 Device access: if Fa<1 only
---------------------------------------------------------------------------------------
 \revision date: 26.09.2016 13:17
 **************************************************************************************/
int CALLTYPE GSV86CANsimulateDfilter(int DevNo, int Analyze_Ftyp, double StartVal, double EndVal, double Fa, int Points, char* Filepath);

#ifdef __cplusplus
}
#endif

#endif
